;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "modus-themes" "20260505.1940"
  "Elegant, highly legible and customizable themes."
  '((emacs "28.1"))
  :url "https://github.com/protesilaos/modus-themes"
  :commit "b4eca2c241b4cfd23637f7620bb7f8e6a96ecbb7"
  :revdesc "b4eca2c241b4"
  :keywords '("faces" "theme" "accessibility")
  :authors '(("Protesilaos" . "info@protesilaos.com"))
  :maintainers '(("Protesilaos" . "info@protesilaos.com")))
